@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: conflogin.php,v 1.42 2009/02/07 22:28:28 gruberroland Exp $
+$Id: conflogin.php,v 1.45 2009/10/27 18:46:33 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2009  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,9 @@ include_once('../../lib/config.inc');
 include_once('../../lib/status.inc');
 
 // start session
-session_save_path("../../sess");
+if (strtolower(session_module_name()) == 'files') {
+	session_save_path("../../sess");
+}
 @session_start();
 
 setlanguage();
@@ -75,7 +77,7 @@ echo $_SESSION['header'];
 			echo "//-->\n";
 			echo "</script>\n";
 		?>
-		<p align="center"><a href="http://lam.sourceforge.net" target="_blank">
+		<p align="center"><a href="http://www.ldap-account-manager.org/" target="_blank">
 			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
 		</p>
 		<hr><br><br>
