@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: confmain.php,v 1.103 2009/03/07 16:22:30 gruberroland Exp $
+$Id: confmain.php,v 1.112 2009/11/13 20:12:34 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2009  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
@@ -38,7 +38,9 @@ include_once("../../lib/config.inc");
 include_once("../../lib/modules.inc");
 
 // start session
-session_save_path("../../sess");
+if (strtolower(session_module_name()) == 'files') {
+	session_save_path("../../sess");
+}
 @session_start();
 
 setlanguage();
@@ -74,44 +76,44 @@ if ((!isset($_SESSION['conf_isAuthenticated']) || !($_SESSION['conf_isAuthentica
 }
 $_SESSION['conf_isAuthenticated'] = $conf->getName();
 
-// check if button was pressed and if we have to save the setting or go back to login
-if (isset($_POST['back']) || isset($_POST['submitconf']) || isset($_POST['editmodules']) || isset($_POST['edittypes'])){
-	// go to final page
-	if (isset($_POST['submitconf'])){
-		saveSettings();
-	}
-	// go to modules page
-	elseif (isset($_POST['editmodules'])){
-		metaRefresh("confmodules.php");
-		exit;
-	}
-	// go to types page
-	elseif (isset($_POST['edittypes'])){
-		metaRefresh("conftypes.php");
-		exit;
-	}
-	// back to login
-	else if (isset($_POST['back'])){
-		metaRefresh("../login.php");
-		exit;
+// check if user canceled editing
+if (isset($_POST['cancelSettings'])) {
+	metaRefresh("../login.php");
+	exit;
+}
+
+$errorsToDisplay = array();
+
+// check if button was pressed and if we have to save the settings or go to another tab
+if (isset($_POST['saveSettings']) || isset($_POST['editmodules'])
+	|| isset($_POST['edittypes']) || isset($_POST['generalSettingsButton'])
+	|| isset($_POST['moduleSettings'])) {
+	$errorsToDisplay = checkInput();
+	if (sizeof($errorsToDisplay) == 0) {
+		// go to final page
+		if (isset($_POST['saveSettings'])) {
+			metaRefresh("confsave.php");
+			exit;
+		}
+		// go to modules page
+		elseif (isset($_POST['editmodules'])) {
+			metaRefresh("confmodules.php");
+			exit;
+		}
+		// go to types page
+		elseif (isset($_POST['edittypes'])) {
+			metaRefresh("conftypes.php");
+			exit;
+		}
+		// go to module settings page
+		elseif (isset($_POST['moduleSettings'])) {
+			metaRefresh("moduleSettings.php");
+			exit;
+		}
 	}
 }
 
 
-// check if user comes from types page
-if (isset($_GET["typesback"])) {
-	// check if a new account type was added
-	if (isset($_GET["typeschanged"])) {
-		metaRefresh("confmodules.php");
-		exit;
-	}
-}
-
-// type information
-if (!isset($_SESSION['conf_accountTypes'])) $_SESSION['conf_accountTypes'] = $conf->get_ActiveTypes();
-if (!isset($_SESSION['conf_accountTypesOld'])) $_SESSION['conf_accountTypesOld'] = $conf->get_ActiveTypes();
-if (!isset($_SESSION['conf_typeSettings'])) $_SESSION['conf_typeSettings'] = $conf->get_typeSettings();
-
 // index for tab order
 $tabindex = 1;
 
@@ -124,7 +126,7 @@ echo ("</head>\n");
 echo ("<body onload=\"configLoginMethodChanged()\">\n");
 echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
 echo "<script type=\"text/javascript\" src=\"config.js\"></script>\n";
-echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
+echo ("<p align=\"center\"><a href=\"http://www.ldap-account-manager.org/\" target=\"new_window\">".
 	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p>&nbsp;</p>\n");
 
 if (!$conf->isWritable()) {
@@ -133,17 +135,90 @@ if (!$conf->isWritable()) {
 }
 
 // display error messages
-if (isset($_SESSION['conf_errors'])) {
-	for ($i = 0; $i < sizeof($_SESSION['conf_errors']); $i++) {
-		call_user_func_array('StatusMessage', $_SESSION['conf_errors'][$i]);
+if (sizeof($errorsToDisplay) > 0) {
+	for ($i = 0; $i < sizeof($errorsToDisplay); $i++) {
+		call_user_func_array('StatusMessage', $errorsToDisplay[$i]);
 	}
 	echo "<br>";
 }
 
 // display formular
 echo ("<form action=\"confmain.php\" method=\"post\">\n");
+echo "<table border=0 width=\"100%\" style=\"border-collapse: collapse;\">\n";
+echo "<tr valign=\"top\"><td style=\"border-bottom: 1px solid;padding:0px;\" colspan=2>";
+// show tabs
+echo "<table width=\"100%\" border=0 style=\"border-collapse: collapse;\">";
+echo "<tr>\n";
+	$buttonSpace = '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
+	// general settings
+	echo "<td class=\"settingsTab\">\n";
+	echo "<table class=\"settingsTab\" width=\"100%\">\n";
+	echo "<tr><td class=\"settingsActiveTab\" onclick=\"document.getElementsByName('generalSettingsButton')[0].click();\"";
+	echo " align=\"center\">\n";
+	$buttonStyle = 'background-image: url(../../graphics/bigTools.png);';
+	echo "<input style=\"" . $buttonStyle . "\" name=\"generalSettingsButton\" type=\"submit\" value=\"" . $buttonSpace . _('General settings') . "\"";
+	echo ">\n";
+	echo "</td></tr></table>\n";
+	echo '</td>';
+	// account types
+	echo "<td class=\"settingsTab\">\n";
+	echo "<table class=\"settingsTab\" width=\"100%\">\n";
+	echo "<tr><td onclick=\"document.getElementsByName('edittypes')[0].click();\"";
+	echo " align=\"center\">\n";
+	$buttonStyle = 'background-image: url(../../graphics/gear.png);';
+	echo "<input style=\"" . $buttonStyle . "\" name=\"edittypes\" type=\"submit\" value=\"" . $buttonSpace . _('Account types') . "\"";
+	echo ">\n";
+	echo "</td></tr></table>\n";
+	echo '</td>';
+	// module selection
+	echo "<td class=\"settingsTab\">\n";
+	echo "<table class=\"settingsTab\" width=\"100%\">\n";
+	echo "<tr><td onclick=\"document.getElementsByName('editmodules')[0].click();\"";
+	echo " align=\"center\">\n";
+	$buttonStyle = 'background-image: url(../../graphics/modules.png);';
+	echo "<input style=\"" . $buttonStyle . "\" name=\"editmodules\" type=\"submit\" value=\"" . $buttonSpace . _('Modules') . "\"";
+	echo ">\n";
+	echo "</td></tr></table>\n";
+	echo '</td>';
+	// module settings
+	echo "<td class=\"settingsTab\">\n";
+	echo "<table class=\"settingsTab\" width=\"100%\">\n";
+	echo "<tr><td onclick=\"document.getElementsByName('moduleSettings')[0].click();\"";
+	echo " align=\"center\">\n";
+	$buttonStyle = 'background-image: url(../../graphics/moduleSettings.png);';
+	echo "<input style=\"" . $buttonStyle . "\" name=\"moduleSettings\" type=\"submit\" value=\"" . $buttonSpace . _('Module settings') . "\"";
+	echo ">\n";
+	echo "</td></tr></table>\n";
+	echo '</td>';
+	echo "<td width=\"100%\">&nbsp;</td>";
+	// spacer
+	echo "<td width=\"100%\">&nbsp;</td>";
+	// save button
+	echo "<td class=\"settingsTab\">\n";
+	echo "<table class=\"settingsTab\" width=\"100%\">\n";
+	echo "<tr><td onclick=\"document.getElementsByName('saveSettings')[0].click();\"";
+	echo " align=\"center\">\n";
+	$buttonStyle = 'background-image: url(../../graphics/pass.png);';
+	echo "<input style=\"" . $buttonStyle . "\" name=\"saveSettings\" type=\"submit\" value=\"" . $buttonSpace . _('Save') . "\"";
+	echo ">\n";
+	echo "</td></tr></table>\n";
+	echo '</td>';
+	// cancel button
+	echo "<td class=\"settingsTab\">\n";
+	echo "<table class=\"settingsTab\" width=\"100%\">\n";
+	echo "<tr><td onclick=\"document.getElementsByName('cancelSettings')[0].click();\"";
+	echo " align=\"center\">\n";
+	$buttonStyle = 'background-image: url(../../graphics/fail.png);';
+	echo "<input style=\"" . $buttonStyle . "\" name=\"cancelSettings\" type=\"submit\" value=\"" . $buttonSpace . _('Cancel') . "\"";
+	echo ">\n";
+	echo "</td></tr></table>\n";
+	echo '</td>';
+	echo "</tr></table>\n";		
+// end tabs
+echo "</td></tr>\n";
 
-echo ("<fieldset><legend><b>" . _("Server settings") . "</b></legend><br>\n");
+echo "<tr><td><br><br>\n";
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/profiles.png\" alt=\"profiles.png\"> <b>" . _("Server settings") . "</b></legend><br>\n");
 echo ("<table border=0>");
 // serverURL
 echo ("<tr><td align=\"right\"><b>" . _("Server address") . " *: </b></td>".
@@ -154,6 +229,25 @@ echo "<td>";
 printHelpLink(getHelp('', '201'), '201');
 echo "</td></tr>\n";
 $tabindex++;
+// use TLS
+echo "<tr><td align=\"right\"><b>" . _("Activate TLS") . ": </b></td>\n";
+echo "<td align=\"left\">\n";
+echo "<select tabindex=\"$tabindex\" size=1 name=\"useTLS\">";
+$useTLS = $conf->getUseTLS();
+if (isset($useTLS) && ($useTLS == 'yes')) {
+	echo "<option value=\"yes\" selected>" . _("yes") . "</option>";
+	echo "<option value=\"no\">" . _("no") . "</option>";
+}
+else {
+	echo "<option value=\"yes\">" . _("yes") . "</option>";
+	echo "<option value=\"no\" selected>" . _("no") . "</option>";
+}
+echo "</select>\n";
+echo "</td>\n";
+echo "<td>";
+printHelpLink(getHelp('', '201'), '201');
+echo "</td></tr>\n";
+$tabindex++;
 
 // new line
 echo ("<tr><td colspan=3>&nbsp;</td></tr>");
@@ -225,63 +319,7 @@ echo ("</fieldset>");
 
 echo ("<br>");
 
-echo ("<fieldset><legend><b>" . _("Account types and modules") . "</b></legend><br>\n");
-
-// Account modules
-$types = $conf->get_ActiveTypes();
-for ($i = 0; $i < sizeof($types); $i++) {
-	$moduleNames = $conf->get_AccountModules($types[$i]);
-	for ($m = 0; $m < sizeof($moduleNames); $m++) $moduleNames[$m] = getModuleAlias($moduleNames[$m], $types[$i]);
-	echo "<b>" . getTypeAlias($types[$i]) . ": </b>" . implode(", ", $moduleNames) . "<br>\n";
-}
-echo "<br>\n";
-echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"edittypes\" value=\"" . _("Edit account types") . "\">&nbsp;&nbsp;";
-$tabindex++;
-echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"editmodules\" value=\"" . _("Edit modules") . "\">&nbsp;&nbsp;";
-printHelpLink(getHelp('', '217'), '217');
-$tabindex++;
-
-echo ("</fieldset>");
-
-echo ("<br>");
-
-
-// module settings
-
-// get list of scopes of modules
-$scopes = array();
-for ($m = 0; $m < sizeof($types); $m++) {
-	$mods = $conf->get_AccountModules($types[$m]);
-	for ($i = 0; $i < sizeof($mods); $i++) $scopes[$mods[$i]][] = $types[$m];
-}
-
-// get module options
-$options = getConfigOptions($scopes);
-// get current setting
-$old_options = $conf->get_moduleSettings();
-
-
-// display module boxes
-$modules = array_keys($options);
-$_SESSION['conf_types'] = array();
-for ($i = 0; $i < sizeof($modules); $i++) {
-	if (sizeof($options[$modules[$i]]) < 1) continue;
-	echo "<fieldset>\n";
-	$icon = '';
-	$module = new $modules[$i]('none');
-	$iconImage = $module->getIcon();
-	if ($iconImage != null) {
-		$icon = '<img align="middle" src="../../graphics/' . $iconImage . '" alt="' . $iconImage . '"> ';
-	}
-	echo "<legend>$icon<b>" . getModuleAlias($modules[$i], "none") . "</b></legend><br>\n";
-	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, 'config');
-	$_SESSION['conf_types'] = array_merge($configTypes, $_SESSION['conf_types']);
-	echo "</fieldset>\n";
-	echo "<br>";
-}
-
-
-echo ("<fieldset><legend><b>" . _("Language settings") . "</b></legend><br>\n");
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/language.png\" alt=\"language.png\"> <b>" . _("Language settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
 
 // language
@@ -326,7 +364,7 @@ echo ("</fieldset>\n");
 echo ("<br>\n");
 
 // script settings
-echo ("<fieldset><legend><b>" . _("Script settings") . "</b></legend><br>\n");
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/lamdaemon.png\" alt=\"lamdaemon.png\"> <b>" . _("Script settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
 
 echo ("<tr><td align=\"right\"><b>".
@@ -393,7 +431,7 @@ echo ("</fieldset>\n");
 echo ("<br>\n");
 
 // security setings
-echo ("<fieldset><legend><b>" . _("Security settings") . "</b></legend><br>\n");
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/security.png\" alt=\"security.png\"> <b>" . _("Security settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
 // login method
 echo ("<tr><td align=\"right\"><b>".
@@ -462,38 +500,22 @@ echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
 $tabindex++;
 echo ("</table>\n");
 echo ("</fieldset>\n");
-echo ("<p>&nbsp;</p>\n");
-
-
-// buttons
-echo ("<table border=0>\n");
-
-echo "<tr>";
-echo "<td align=\"left\"><pre>";
-	echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"submitconf\" value=\"" . _("Ok") . "\">";
-	$tabindex++;
-	echo "&nbsp;";
-	echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"back\" value=\"" . _("Cancel") . "\"\n";
-	$tabindex++;
-
-echo ("></pre></td></tr>\n");
-
-echo ("</table>\n");
-
-echo ("<p>&nbsp;</p>");
 
 echo ("<p>* = ". _("required") . "</p>");
+echo ("<p>&nbsp;</p>\n");
 
+echo '</td></tr></table>';
 echo ("</form>\n");
 echo ("</body>\n");
 echo ("</html>\n");
 
 
 /**
- * Saves the entered settings.
+ * Checks user input and saves the entered settings.
  *
+ * @return array list of errors
  */
-function saveSettings() {
+function checkInput() {
 	$conf = &$_SESSION['conf_config'];
 	$types = $conf->get_ActiveTypes();
 
@@ -509,6 +531,7 @@ function saveSettings() {
 	if (!$conf->set_ServerURL($_POST['serverurl'])) {
 		$errors[] = array("ERROR", _("Server address is invalid!"));
 	}
+	$conf->setUseTLS($_POST['useTLS']);
 	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
 		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
 	}
@@ -567,69 +590,7 @@ function saveSettings() {
 		}
 	}
 
-	// check module options
-	// create option array to check and save
-	$options = array();
-	$opt_keys = array_keys($_SESSION['conf_types']);
-	for ($i = 0; $i < sizeof($opt_keys); $i++) {
-		$element = $opt_keys[$i];
-		// text fields
-		if ($_SESSION['conf_types'][$element] == "text") {
-			$options[$element] = array($_POST[$element]);
-		}
-		// checkboxes
-		elseif ($_SESSION['conf_types'][$element] == "checkbox") {
-			if (isset($_POST[$element]) && ($_POST[$element] == "on")) $options[$element] = array('true');
-			else $options[$element] = array('false');
-		}
-		// dropdownbox
-		elseif ($_SESSION['conf_types'][$element] == "select") {
-			$options[$element] = array($_POST[$element]);
-		}
-		// multiselect
-		elseif ($_SESSION['conf_types'][$element] == "multiselect") {
-			$options[$element] = $_POST[$element];  // value is already an array
-		}
-		// textarea
-		elseif ($_SESSION['conf_types'][$element] == "textarea") {
-			$options[$element] = explode("\r\n", $_POST[$element]);
-		}
-	}
-
-	// get list of scopes of modules
-	$scopes = array();
-	for ($m = 0; $m < sizeof($types); $m++) {
-		$mods = $conf->get_AccountModules($types[$m]);
-		for ($i = 0; $i < sizeof($mods); $i++) $scopes[$mods[$i]][] = $types[$m];
-	}
-	// check options
-	$errors = array_merge($errors, checkConfigOptions($scopes, $options));
-	// print error messages if any
-	if (sizeof($errors) > 0) {
-		$_SESSION['conf_errors'] = $errors;
-		$conf->set_moduleSettings($options);
-	}
-	// save settings if no errors occured
-	else {
-		// page head
-		echo $_SESSION['header'];
-		echo "<title>" . _("LDAP Account Manager Configuration") . "</title>\n";
-		echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-		echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
-		echo "</head><body>\n";
-		echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
-			"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p><hr><br><br>");
-		$conf->set_moduleSettings($options);
-		$conf->save();
-		echo ("<br><br><br><br><br><a href=\"../login.php\" target=\"_top\">" . _("Back to Login") . "</a>");
-		echo("</body></html>");
-		// remove settings from session
-		$sessionKeys = array_keys($_SESSION);
-		for ($i = 0; $i < sizeof($sessionKeys); $i++) {
-			if (substr($sessionKeys[$i], 0, 5) == "conf_") unset($_SESSION[$sessionKeys[$i]]);
-		}
-		exit();
-	}
+	return $errors;
 }
 
 ?>
