@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: mainlogin.php,v 1.6 2009/02/07 22:28:28 gruberroland Exp $
+$Id: mainlogin.php,v 1.10 2009/11/06 19:15:56 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2009  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,9 @@ include_once('../../lib/config.inc');
 include_once('../../lib/status.inc');
 
 // start session
-session_save_path("../../sess");
+if (strtolower(session_module_name()) == 'files') {
+	session_save_path("../../sess");
+}
 @session_start();
 
 setlanguage();
@@ -44,9 +46,9 @@ setlanguage();
 // remove settings from session
 if (isset($_SESSION["mainconf_password"])) unset($_SESSION["mainconf_password"]);
 
+$cfgMain = new LAMCfgMain();
 // check if user entered a password
 if (isset($_POST['passwd'])) {
-	$cfgMain = new LAMCfgMain();
 	if (isset($_POST['passwd']) && ($cfgMain->checkPassword($_POST['passwd']))) {
 		$_SESSION["mainconf_password"] = $_POST['passwd'];
 		metaRefresh("mainmanage.php");
@@ -83,10 +85,17 @@ echo $_SESSION['header'];
 			echo "</script>\n";
 			echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
 		?>
-		<p align="center"><a href="http://lam.sourceforge.net" target="_blank">
+		<p align="center"><a href="http://www.ldap-account-manager.org/" target="_blank">
 			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
 		</p>
-		<hr><br><br>
+		<hr><br>
+		<?php
+			// check if config file is writable
+			if (!$cfgMain->isWritable()) {
+				StatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.');
+			}
+		?>
+		<br>
 		<!-- form to change main options -->
 		<form action="mainlogin.php" method="post">
 		<table align="center" border="2" rules="none" bgcolor="white">
