@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: mainmanage.php,v 1.12 2009/02/07 22:28:28 gruberroland Exp $
+$Id: mainmanage.php,v 1.18 2009/11/06 19:15:56 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2009  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,9 @@ include_once('../../lib/config.inc');
 include_once('../../lib/status.inc');
 
 // start session
-session_save_path("../../sess");
+if (strtolower(session_module_name()) == 'files') {
+	session_save_path("../../sess");
+}
 @session_start();
 
 setlanguage();
@@ -62,7 +64,7 @@ echo $_SESSION['header'];
 		<link rel="shortcut icon" type="image/x-icon" href="../../graphics/favicon.ico">
 	</head>
 	<body>
-		<p align="center"><a href="http://lam.sourceforge.net" target="_blank">
+		<p align="center"><a href="http://www.ldap-account-manager.org/" target="_blank">
 			<img src="../../graphics/banner.jpg" border=1 alt="LDAP Account Manager"></a>
 		</p>
 		<hr><br>
@@ -103,8 +105,8 @@ if (isset($_POST['submit'])) {
 				continue;
 			}
 			// check each line
-			$ipRegex = '^[0-9\\.\\*]+$';
-			if (!ereg($ipRegex, $allowedHostsList[$i]) || (strlen($allowedHostsList[$i]) > 15)) {
+			$ipRegex = '/^[0-9\\.\\*]+$/';
+			if (!preg_match($ipRegex, $allowedHostsList[$i]) || (strlen($allowedHostsList[$i]) > 15)) {
 				$errors[] = sprintf(_("The IP address %s is invalid!"), $allowedHostsList[$i]);
 			}
 		}
@@ -118,7 +120,7 @@ if (isset($_POST['submit'])) {
 	if ($_POST['logDestination'] == "none") $cfg->logDestination = "NONE";
 	elseif ($_POST['logDestination'] == "syslog") $cfg->logDestination = "SYSLOG";
 	else {
-		if (isset($_POST['logFile']) && ($_POST['logFile'] != "") && eregi("^[a-z0-9/\\\\:\\._-]+$", $_POST['logFile'])) {
+		if (isset($_POST['logFile']) && ($_POST['logFile'] != "") && preg_match("/^[a-z0-9\\/\\\\:\\._-]+$/i", $_POST['logFile'])) {
 			$cfg->logDestination = $_POST['logFile'];
 		}
 		else $errors[] = _("The log file is empty or contains invalid characters! Valid characters are: a-z, A-Z, 0-9, /, \\, ., :, _ and -.");
@@ -143,6 +145,11 @@ if (isset($_POST['submit'])) {
 		exit();
 	}
 }
+
+// check if config file is writable
+if (!$cfg->isWritable()) {
+	StatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.');
+}
 ?>
 
 		<br>
@@ -355,7 +362,9 @@ if (isset($_POST['submit'])) {
 			<TR>
 				<TD>
 					<BR>
+					<?php if ($cfg->isWritable()) { ?>
 					<input type="submit" name="submit" value=" <?php echo _("Ok"); ?> ">
+					<?php } ?>
 				</TD>
 			</TR>
 			</table>
