@@ -1,8 +1,8 @@
 <?php
 /*
-	$Id: delete.php,v 1.70 2009/02/07 19:24:54 gruberroland Exp $
+	$Id: delete.php,v 1.74 2009/10/28 16:35:41 gruberroland Exp $
 
-	This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+	This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
 	Copyright (C) 2003 - 2006  Tilo Lutz
 	Copyright (C) 2007 - 2009  Roland Gruber
 
@@ -159,7 +159,7 @@ if ($_POST['delete']) {
 					break;
 				}
 			}
-		}		
+		}
 		if (!$stopprocessing) {
 			// load attributes
 			foreach ($moduleNames as $singlemodule) {
@@ -168,7 +168,6 @@ if ($_POST['delete']) {
 				if (is_array($temp)) {
 					// merge changes
 					$DNs = array_keys($temp);
-					// *** fixme don't include references
 					$attributes = array_merge_recursive($temp, $attributes);
 					for ($i=0; $i<count($DNs); $i++) {
 						$ops = array_keys($temp[$DNs[$i]]);
@@ -255,7 +254,7 @@ if ($_POST['delete']) {
 */
 function getChildCount($dn) {
 	$return = 0;
-	$sr = @ldap_search($_SESSION['ldap']->server(), escapeDN($dn), 'objectClass=*', array('dn'), 0);
+	$sr = @ldap_search($_SESSION['ldap']->server(), escapeDN($dn), 'objectClass=*', array('dn'), 0, 0, 0, LDAP_DEREF_NEVER);
 	if ($sr) {
 		$entries = ldap_get_entries($_SESSION['ldap']->server(), $sr);
 		$return = $entries['count'] - 1;
