@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: help.php,v 1.30 2009/02/07 19:24:54 gruberroland Exp $
+$Id: help.php,v 1.32 2009/10/27 18:46:33 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
                 2008 - 2009  Roland Gruber
 
@@ -38,7 +38,9 @@ include_once("../lib/ldap.inc");
 /** configuration */
 include_once("../lib/config.inc");
 
-session_save_path("../sess");
+if (strtolower(session_module_name()) == 'files') {
+	session_save_path("../sess");
+}
 @session_start();
 
 /** status messages */
