@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: initsuff.php,v 1.18 2008/09/04 17:43:31 gruberroland Exp $
+$Id: initsuff.php,v 1.22 2009/11/24 15:19:38 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
@@ -58,7 +58,7 @@ if ($_POST['add_suff'] || $_POST['cancel']) {
 		// add entries
 		for ($i = 0; $i < sizeof($new_suff); $i++) {
 			// check if entry is already present
-			$info = @ldap_search($_SESSION['ldap']->server(), escapeDN($new_suff[$i]), "", array());
+			$info = @ldap_read($_SESSION['ldap']->server(), escapeDN($new_suff[$i]), "objectclass=*", array('dn'), 0, 0, 0, LDAP_DEREF_NEVER);
 			$res = @ldap_get_entries($_SESSION['ldap']->server(), $info);
 			if ($res) continue;
 			$suff = $new_suff[$i];
@@ -100,7 +100,7 @@ if ($_POST['add_suff'] || $_POST['cancel']) {
 						// create missing entries
 						for ($k = sizeof($subsuffs) - 1; $k >= 0; $k--) {
 							// check if subsuffix is present
-							$info = @ldap_search($_SESSION['ldap']->server(), escapeDN($subsuffs[$k]), "", array());
+							$info = @ldap_read($_SESSION['ldap']->server(), escapeDN($subsuffs[$k]), "objectclass=*", array('dn'), 0, 0, 0, LDAP_DEREF_NEVER);
 							$res = @ldap_get_entries($_SESSION['ldap']->server(), $info);
 							if (!$res) {
 								$suffarray = explode(",", $subsuffs[$k]);
