@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: userlink.php,v 1.19 2008/09/04 17:43:53 gruberroland Exp $
+$Id: userlink.php,v 1.22 2009/10/28 16:36:08 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
@@ -77,7 +77,7 @@ else {
 function search_username($name) {
 	$filter = "(uid=$name)";
 	$attrs = array();
-	$sr = @ldap_search($_SESSION['ldap']->server(), escapeDN($_SESSION['config']->get_Suffix('user')), $filter, $attrs);
+	$sr = @ldap_search($_SESSION['ldap']->server(), escapeDN($_SESSION['config']->get_Suffix('user')), $filter, $attrs, 0, 0, 0, LDAP_DEREF_NEVER);
 	if ($sr) {
 		$info = ldap_get_entries($_SESSION['ldap']->server(), $sr);
 		// return only first DN entry
