@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: login.php,v 1.114 2009/03/07 18:20:03 gruberroland Exp $
+$Id: login.php,v 1.123 2009/11/03 20:57:53 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
 
   This program is free software; you can redistribute it and/or modify
@@ -112,7 +112,10 @@ if (sizeof($criticalErrors) > 0) {
 /** access to configuration options */
 include_once("../lib/config.inc"); // Include config.inc which provides Config class
 
-session_save_path("../sess"); // Set session save path
+// set session save path
+if (strtolower(session_module_name()) == 'files') {
+	session_save_path("../sess");
+}
 session_start(); // Start LDAP Account Manager session
 
 // save last selected login profile
@@ -208,20 +211,20 @@ function display_LoginPage($config_object) {
 		echo "</script>\n";
 	?>
 		<p align="center">
-			<a href="http://lam.sourceforge.net" target="_blank"><img src="../graphics/banner.jpg" border="1" alt="LDAP Account Manager"></a>
+			<a href="http://www.ldap-account-manager.org/" target="_blank"><img src="../graphics/banner.jpg" border="1" alt="LDAP Account Manager"></a>
 		</p>
 		<table width="100%" border="0">
 			<tr>
-				<TD width="50%" align="left">
+				<td width="50%" align="left">
+					<a href="./config/index.php"><IMG alt="configuration" src="../graphics/tools.png">&nbsp;<?php echo _("LAM configuration") ?></a>
+				</td>
+				<TD width="50%" align="right">
 					<?PHP
 						if (!isLAMProVersion()) {
-							echo "<a href=\"http://lam.sourceforge.net/lamPro/index.htm\">" . _("Want more features? Get LAM Pro!") . "</a>";
+							echo "<a href=\"http://www.ldap-account-manager.org/lamcms/lamPro\">" . _("Want more features? Get LAM Pro!") . "</a>";
 						}
 					?>
 				</TD>
-				<td width="50%" align="right">
-					<a href="./config/index.php"><IMG alt="configuration" src="../graphics/tools.png">&nbsp;<?php echo _("LAM configuration") ?></a>
-				</td>
 			</tr>
 		</table>
 		<hr><br><br>
@@ -234,6 +237,14 @@ function display_LoginPage($config_object) {
 				echo "<br>";
 			}
 		}
+		// check TLS
+		$useTLS = $config_object->getUseTLS();
+		if (isset($useTLS) && ($useTLS == "yes")) {
+			if (!function_exists('ldap_start_tls')) {
+				StatusMessage("ERROR", "Your PHP installation does not support TLS encryption!");
+				echo "<br>";
+			}
+		}
 		// check if session expired
 		if (isset($_GET['expired'])) {
 			StatusMessage("ERROR", _("Your session expired, please log in again."));
@@ -401,61 +412,67 @@ function display_LoginPage($config_object) {
 }
 
 // checking if the submitted username/password is correct.
-if(!empty($_POST['checklogin']))
-{
+if(!empty($_POST['checklogin'])) {
 	$_SESSION['lampath'] = realpath('../') . "/";  // Save full path to lam in session
 
 	include_once("../lib/ldap.inc"); // Include ldap.php which provides Ldap class
 
 	$_SESSION['ldap'] = new Ldap($_SESSION['config']); // Create new Ldap object
 
-	if($_POST['passwd'] == "")
-	{
+	if($_POST['passwd'] == "") {
 		$error_message = _("Empty password submitted. Please try again.");
 		display_LoginPage($_SESSION['config']); // Empty password submitted. Return to login page.
 	}
-	else
-	{
+	else {
+		$clientSource = $_SERVER['REMOTE_ADDR'] . '/' . $_SERVER['REMOTE_HOST'];
 		if (get_magic_quotes_gpc() == 1) {
 			$_POST['passwd'] = stripslashes($_POST['passwd']);
 		}
 		$username = $_POST['username'];
 		// search user in LDAP if needed
 		if ($_SESSION['config']->getLoginMethod() == LAMConfig::LOGIN_SEARCH) {
-			$searchLDAP = new Ldap($_SESSION['config']);
-			$searchLDAP->connect('', '');
 			$searchFilter = $_SESSION['config']->getLoginSearchFilter();
 			$searchFilter = str_replace('%USER%', $username ,$searchFilter);
 			$searchSuccess = true;
 			$searchError = '';
-			$searchResult = @ldap_search($searchLDAP->server(), $_SESSION['config']->getLoginSearchSuffix(), $searchFilter, array('dn'));
-			if ($searchResult) {
-				$searchInfo = @ldap_get_entries($searchLDAP->server(), $searchResult);
-				if ($searchInfo) {
-					if ($searchInfo['count'] == 0) {
-						$searchSuccess = false;
-						$searchError = _('Wrong password/user name combination. Please try again.');
-					}
-					elseif ($searchInfo['count'] > 1) {
-						$searchSuccess = false;
-						$searchError = _('The given user name matches multiple LDAP entries.');
+			$searchLDAP = new Ldap($_SESSION['config']);
+			$searchLDAPResult = $searchLDAP->connect('', '', true);
+			if (! ($searchLDAPResult == 0)) {
+				$searchSuccess = false;
+				$searchError = _('Cannot connect to specified LDAP server. Please try again.') . ' ' . @ldap_error($searchLDAP->server());
+			}
+			else {
+				$searchResult = @ldap_search($searchLDAP->server(), $_SESSION['config']->getLoginSearchSuffix(), $searchFilter, array('dn'), 0, 0, 0, LDAP_DEREF_NEVER);
+				if ($searchResult) {
+					$searchInfo = @ldap_get_entries($searchLDAP->server(), $searchResult);
+					if ($searchInfo) {
+						if ($searchInfo['count'] == 0) {
+							$searchSuccess = false;
+							$searchError = _('Wrong password/user name combination. Please try again.');
+						}
+						elseif ($searchInfo['count'] > 1) {
+							$searchSuccess = false;
+							$searchError = _('The given user name matches multiple LDAP entries.');
+						}
+						else {
+							$username = $searchInfo[0]['dn'];
+						}
 					}
 					else {
-						$username = $searchInfo[0]['dn'];
+						$searchSuccess = false;
+						$searchError = _('Unable to find the user name in LDAP.');
+						if (ldap_errno($searchLDAP->server()) != 0) $searchError .= ' ' . ldap_error($searchLDAP->server());
 					}
 				}
 				else {
 					$searchSuccess = false;
-					$searchError = _('Unable to find the user name in LDAP.') . ' ' . ldap_error($searchLDAP->server());
+					$searchError = _('Unable to find the user name in LDAP.');
+					if (ldap_errno($searchLDAP->server()) != 0) $searchError .= ' ' . ldap_error($searchLDAP->server());
 				}
 			}
-			else {
-				$searchSuccess = false;
-				$searchError = _('Unable to find the user name in LDAP.') . ' ' . ldap_error($searchLDAP->server());
-			}
 			if (!$searchSuccess) {
 				$error_message = $searchError;
-				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in. ' . $searchError . '');
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in. ' . $searchError . '');
 				$searchLDAP->close();
 				display_LoginPage($_SESSION['config']);
 				exit();
@@ -477,34 +494,38 @@ if(!empty($_POST['checklogin']))
 			$_SESSION['sec_client_ip'] = $_SERVER['REMOTE_ADDR'];
 			$_SESSION['sec_sessionTime'] = time();
 			// logging
-			logNewMessage(LOG_NOTICE, 'User ' . $_POST['username'] . ' successfully logged in.');
+			logNewMessage(LOG_NOTICE, 'User ' . $_POST['username'] . ' (' . $clientSource . ') successfully logged in.');
 			// Load main frame
 			metaRefresh("./main.php");
 			die();
 		}
 		else {
 			if ($result === False) {
+				// connection failed
 				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
-				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
-				display_LoginPage($_SESSION['config']); // connection failed
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
+				display_LoginPage($_SESSION['config']);
 				exit();
 			}
 			elseif ($result == 81) {
+				// connection failed
 				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
-				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
-				display_LoginPage($_SESSION['config']); // connection failed
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
+				display_LoginPage($_SESSION['config']);
 				exit();
 			}
 			elseif ($result == 49) {
+				// user name/password invalid. Return to login page.
 				$error_message = _("Wrong password/user name combination. Please try again.");
-				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (wrong password).');
-				display_LoginPage($_SESSION['config']); // Username/password invalid. Return to login page.
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (wrong password).');
+				display_LoginPage($_SESSION['config']);
 				exit();
 			}
 			else {
+				// other errors
 				$error_message = _("LDAP error, server says:") .  "\n<br>($result) " . ldap_err2str($result);
-				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
-				display_LoginPage($_SESSION['config']); // other errors
+				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
+				display_LoginPage($_SESSION['config']);
 				exit();
 			}
 		}
