@@ -1,8 +1,8 @@
 <?php
 /*
-$Id: ou_edit.php,v 1.26 2009/02/07 22:56:36 gruberroland Exp $
+$Id: ou_edit.php,v 1.29 2009/10/27 18:46:33 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2008  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
@@ -58,7 +58,7 @@ if (isset($_POST['createOU']) || isset($_POST['deleteOU'])) {
 	// new ou
 	if (isset($_POST['createOU'])) {
 		// create ou if valid
-		if (eregi("^[a-z0-9 _\\-]+$", $_POST['newOU'])) {
+		if (preg_match("/^[a-z0-9 _\\-]+$/i", $_POST['newOU'])) {
 			// check if ou already exists
 			$new_dn = "ou=" . $_POST['newOU'] . "," . $_POST['parentOU'];
 			if (!in_array($new_dn, $_SESSION['ldap']->search_units($_POST['parentOU']))) {
@@ -147,9 +147,7 @@ function display_main() {
 	echo $_SESSION['header'];
 	echo ("<title>OU-Editor</title>\n");
 	echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n");
-	for ($i = 0; $i < sizeof($types); $i++) {
-		echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/type_" . $types[$i] . ".css\">\n");
-	}
+	echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/type_user.css\">\n");
 	echo ("</head>\n");
 	echo ("<body>\n");
 	echo "<script type=\"text/javascript\" src=\"wz_tooltip.js\"></script>\n";
