@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: lamdaemonTest.php,v 1.13 2008/12/18 14:44:42 gruberroland Exp $
+$Id: lamdaemonTest.php,v 1.17 2009/12/12 18:21:11 gruberroland Exp $
 
-  This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2006 - 2007  Roland Gruber
+  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
+  Copyright (C) 2006 - 2009  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,6 @@ setlanguage();
 
 echo $_SESSION['header'];
 
-
 echo "<title></title>\n";
 echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
 echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_user.css\">\n";
@@ -155,7 +154,7 @@ function lamTestLamdaemon($command, $stopTest, $handle, $testText) {
 				break;
 			}
 			usleep(100);
-			$read = split("\n", trim(fread($shell, 100000)));
+			$read = explode("\n", trim(fread($shell, 100000)));
 			if ((sizeof($read) == 1) && (!isset($read[0]) || ($read[0] == ""))) continue;
 			for ($i = 0; $i < sizeof($read); $i++) {
 				$return[] = $read[$i];
@@ -181,7 +180,7 @@ function lamTestLamdaemon($command, $stopTest, $handle, $testText) {
 			echo "<td>" . $failImage . "&nbsp;&nbsp;</td>\n";
 			echo "<td>\n";
 			for ($i = 0; $i < sizeof($return); $i++) {
-				call_user_func_array('StatusMessage', split(",", $return[$i]));
+				call_user_func_array('StatusMessage', explode(",", $return[$i]));
 			}
 			echo "</td>\n";
 			$stopTest = true;
@@ -200,6 +199,7 @@ function lamTestLamdaemon($command, $stopTest, $handle, $testText) {
  * @param boolean $testQuota true, if Quotas should be checked
  */
 function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota) {
+	$SPLIT_DELIMITER = "###x##y##x###";
 	$okImage = "<img src=\"../../graphics/pass.png\" alt=\"\">\n";
 	$failImage = "<img src=\"../../graphics/fail.png\" alt=\"\">\n";
 	
@@ -278,13 +278,7 @@ function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota) {
 		echo "<tr class=\"userlist\">\n<td nowrap>" . _("SSH connection") . "&nbsp;&nbsp;</td>\n";
 		flush();
 		$sshOk = false;
-		$serverNameParts = explode(",", $serverName);
-		if (sizeof($serverNameParts) > 1) {
-			$handle = @ssh2_connect($serverNameParts[0], $serverNameParts[1]);
-		}
-		else {
-			$handle = @ssh2_connect($serverName);
-		}
+		$handle = lamTestConnectSSH($serverName);
 		if ($handle) {
 			if (@ssh2_auth_password($handle, $userName, $credentials[1])) {
 				$sshOk = true;
@@ -304,14 +298,14 @@ function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota) {
 
 	flush();
 	
-	$stopTest = lamTestLamdaemon("+ test basic\n", $stopTest, $handle, _("Execute lamdaemon"));
+	$stopTest = lamTestLamdaemon("+" . $SPLIT_DELIMITER . "test" . $SPLIT_DELIMITER . "basic\n", $stopTest, $handle, _("Execute lamdaemon"));
 	if ($testQuota) {
-		$handle = @ssh2_connect($serverName);
+		$handle = lamTestConnectSSH($serverName);
 		@ssh2_auth_password($handle, $userName, $credentials[1]);
-		$stopTest = lamTestLamdaemon("+ test quota\n", $stopTest, $handle, _("Lamdaemon: Quota module installed"));
-		$handle = @ssh2_connect($serverName);
+		$stopTest = lamTestLamdaemon("+" . $SPLIT_DELIMITER . "test" . $SPLIT_DELIMITER . "quota\n", $stopTest, $handle, _("Lamdaemon: Quota module installed"));
+		$handle = lamTestConnectSSH($serverName);
 		@ssh2_auth_password($handle, $userName, $credentials[1]);
-		$stopTest = lamTestLamdaemon("+ quota get user\n", $stopTest, $handle, _("Lamdaemon: read quotas"));
+		$stopTest = lamTestLamdaemon("+" . $SPLIT_DELIMITER . "quota" . $SPLIT_DELIMITER . "get" . $SPLIT_DELIMITER . "user\n", $stopTest, $handle, _("Lamdaemon: read quotas"));
 	}
 
 	echo "</table><br>\n";
@@ -319,4 +313,20 @@ function lamRunLamdaemonTestSuite($serverName, $serverTitle, $testQuota) {
 	echo "<h2>" . _("Lamdaemon test finished.") . "</h2>\n";
 }
 
+/**
+ * Connects to the given SSH server.
+ *
+ * @param String $server server name (e.g. localhost or localhost,1234)
+ * @return object handle
+ */
+function lamTestConnectSSH($server) {
+	$serverNameParts = explode(",", $server);
+	if (sizeof($serverNameParts) > 1) {
+		return @ssh2_connect($serverNameParts[0], $serverNameParts[1]);
+	}
+	else {
+		return @ssh2_connect($server);
+	}
+}
+
 ?>
